
# SEGGER MQTT Client Application

The MQTT Client Applicaiton is a simple commandline-based MQTT client to connect to an MQTT broker.
It can subscribe to topic filters to receive messages or publish to topics.

The MQTT Client Application uses the embOS/IP MQTT add-on and the emSSL SSL/TLS library on top of the host's (i.e. Windows) native TCP/IP stack.
The embOS/IP MQTT add-on and emSSL can be used in the same way on any embedded target.
For a reference target implementation, please refer to [the SEGGER website](https://www.segger.com) or contact SEGGER.

## Usage
```
MQTTClient --pub|--sub [Options]
  --pub              Start the publisher.
  --sub              Start the subscriber.

Options:
  [-h <Hostname>]     Broker to connect to. Host or IP address.
  [-p <Port>]         Port of the broker to connect to.
  [-i <ClientName>]   Name of the client.
  [-t <TopicFilter>]  Topic(s) to subscribe/publish to.
  [-c <Count>]        Message count to receive/publish.
Will Options:
  [-w]                Register will to be sent on disconnect.
  [--will-topic]      Topic to publish will to.
  [--will-payload]    Payload of will to publish.
  [--will-qos <Level>]QoS level of will.
  [--will-retain]     Set retain flag on will.
Security Options:
  [--tls]             Enable use of SSL/TLS.
  [--cert]            Client certificate file.
  [--key]             Private key file.
Publisher only:
  [-m <Message>]      Message to publish.
  [-q <QoSLevel>]     Quality of Service level.
  [-r]                Set retain flag.
  [-d <Seconds>]      Delay after publish.
Subscriber only:
Logging:
  [-v <Level>]        Verbosity level.
  [--debug]           Debug output.
```

### Options

#### -c _Count_
Number of messages to receive or publish before client exits automatically.   
Default: off, unlimited

#### - -cert _Filename_
Set certificate file for client authentication with secured connection.   
The certificate file needs to be a DER encoded RSA certificate.
Default: none

#### -d _Seconds_
Seconds to delay between publish of messages.   
Default: `1`

#### - -debug
Enable diagnostic debug output.   
Default: off

#### -h _Hostname_
Hostname or IP address of the MQTT broker to connect to.   
Default: `iot.eclipse.org`

#### -i _ClientName_
Name of the client that will be passed to the broker. 
The client name has to be unique with most brokers.   
Default: `SEGGER-MQTT-<Random>`

#### - -key _Filename_
Set the private key file for the client certificate.   
The private key file needs to be a DER encoded RSA key.   
Default: none

#### -m _Message_
The message payload to publish.   
Default: `www.SEGGER.com embOS/IP MQTT Demo running.`

#### -p  _Port_
Port of the broker to connect to.   
Default: `1883`

#### - -pub
Start the MQTT Client as publisher.

#### -q _QoSLevel_
Set the Quality of Service for published messages to 0, 1, or 2.   
Default: `0`

#### -r
Set the retain flag for published messages.   
Default: off, no retain

#### - -sub
Start the MQTT Client as subscriber.

#### -t _TopicFilter_
Topic filter to subscribe to or topic to publish to.   
Default: `SEGGER/Demo`

#### - -tls
Enable secured connection using SSL/TLS.   
Default: off, unsecured

#### -v Level
Set the verbosity level for output between 0 and 3.   
Default: `1` 

#### -w
Register a will to be published by the broker when the client unexpectedly disconnects.   
Default: off, no will

#### - -will-payload _Payload_
Payload of will message.   
Default: `MQTT Demo disconnected.`

#### - -will-qos _QoSLevel_
Set the Quality of Service for will message to 0, 1, or 2.   
Default: `0`

#### - -will-retain
Set the retain flag for will message.   
Default: off, no retain

#### - -will-topic _Topic_
Topic to publish will message to.   
Default: `SEGGER/disconnect`

## Examples

`MQTTClient --pub -h iot.eclipse.org -p 1883 -t SEGGER/Demo -m "Hello World from SEGGER MQTT."`   
Connect to broker at iot.eclipse.org:1883 and publish "Hello World from SEGGER MQTT." to "SEGGER/Demo" every second.

`MQTTClient --sub -h iot.eclipse.org -p 1883 -t SEGGER/Demo`   
Connect to broker iot.eclipse.org:1883 and subscribe to "SEGGER/Demo" to receive all published messages from that topic.

`MQTTClient --pub -h 1a2b3c4d5e6f7g.iot.eu-central-1.amazonaws.com -p 8883 -t SEGGER/Demo -m "Hello World from SEGGER MQTT." --tls --cert C:\Temp\aws_cert.der --key C:\Temp\aws_private.der -d 5`   
Securely connect to broker at 1a2b3c4d5e6f7g.iot.eu-central-1.amazonaws.com:8883 using TLS with certificate file aws_cert and private key file aws_private to publish "Hello World from SEGGER MQTT." to "SEGGER/Demo" with 5 second delay.
